summaryrefslogtreecommitdiffstats
path: root/cc/trees/layer_tree_host_common.cc
diff options
context:
space:
mode:
authorjaydasika <jaydasika@chromium.org>2015-10-23 10:29:06 -0700
committerCommit bot <commit-bot@chromium.org>2015-10-23 17:29:46 +0000
commitf18cd96bffe9d683556711d5939157f163feee02 (patch)
tree66aea5f1954bc230a767ca5d1d55afffc88b195d /cc/trees/layer_tree_host_common.cc
parentaebd8ebe5cccb7fce8f446db01f8e9bea8176435 (diff)
downloadchromium_src-f18cd96bffe9d683556711d5939157f163feee02.zip
chromium_src-f18cd96bffe9d683556711d5939157f163feee02.tar.gz
chromium_src-f18cd96bffe9d683556711d5939157f163feee02.tar.bz2
cc: Make property trees support external transforms
This makes the transform tree get updated for changes to the device transform that happen on the compositor thread via calls to LTHI::SetExternalDrawConstraints (this is used by Android WebView). BUG=524106 CQ_INCLUDE_TRYBOTS=tryserver.blink:linux_blink_rel patch from issue 1415183002 at patchset 20001 (http://crrev.com/1415183002#ps20001) Review URL: https://codereview.chromium.org/1414563008 Cr-Commit-Position: refs/heads/master@{#355816}
Diffstat (limited to 'cc/trees/layer_tree_host_common.cc')
-rw-r--r--cc/trees/layer_tree_host_common.cc5
1 files changed, 4 insertions, 1 deletions
diff --git a/cc/trees/layer_tree_host_common.cc b/cc/trees/layer_tree_host_common.cc
index ccffb0f..40184b0 100644
--- a/cc/trees/layer_tree_host_common.cc
+++ b/cc/trees/layer_tree_host_common.cc
@@ -2708,9 +2708,12 @@ void CalculateDrawPropertiesAndVerify(
inputs->property_trees, inputs->page_scale_layer,
inputs->page_scale_factor, inputs->device_scale_factor,
inputs->device_transform);
// Similarly, the device viewport is shared between both trees.
inputs->property_trees->clip_tree.SetViewportClip(
gfx::RectF(gfx::SizeF(inputs->device_viewport_size)));
+ inputs->property_trees->transform_tree.SetDeviceTransform(
+ inputs->device_transform, inputs->root_layer->position());
ComputeVisibleRectsUsingPropertyTrees(
inputs->root_layer, inputs->property_trees,
inputs->can_render_to_separate_surface, &update_layer_list);
@@ -2708,9 +2708,12 @@ void CalculateDrawPropertiesAndVerify(
inputs->page_scale_factor, inputs->device_scale_factor,
inputs->device_transform);
- // Similarly, the device viewport is shared between both trees.
+ // Similarly, the device viewport and device transform are shared
+ // by both trees.
inputs->property_trees->clip_tree.SetViewportClip(
gfx::RectF(gfx::SizeF(inputs->device_viewport_size)));